@@ -167,6 +167,8 @@ private:
     double mjdStart = 0.;
     double mjdEnd = 0.;
     double mjdMedian = 0.;
+    QString minDateObs = "";   // for the coadded image
+    QString maxDateObs = "";   // for the coadded image
 
     // Astrometry
     bool manualCoordsUpdate(Data *scienceData, QString mode);
@@ -200,7 +202,7 @@ private:
     void splitScampHeaders();
     void scampCalcFluxscale();
     int getMaxPhotInst();
-//    void provideHeaderInfo(Data *scienceData);
+//    void provideHeaderInfo(Data *scpublic QMainWindowienceData);
     void buildSourceExtractorCommandOptions();
     void detectionInternal(Data *scienceData, QString minFWHM, QString maxFlag);
     void detectionSourceExtractor(Data *scienceData, QString minFWHM, QString maxFlag);
