@@ -140,7 +140,10 @@ void Controller::skysubPolynomialFit(Data *scienceData)
         }
         // Fit a polynomial to the nodes, subtract the model from the images
         Fitting skyFit;
+        connect(&skyFit, &Fitting::messageAvailable, this, &Controller::messageAvailableReceived);
         skyFit.makePolynomialFit2D(order, skyPolyfitNodes);
+        if (!skyFit.FITSUCCESS) continue;
+
         // TODO: large multi-chip cameras would profit from an internal parallelization
         // I THINK a simple '#pragma omp for' would take care of this automatically
         for (auto &it : scienceData->exposureList[i]) {
@@ -595,7 +598,8 @@ void Controller::skysubModel(Data *scienceData, QString DT, QString DMIN, QStrin
         if (it->activeState != MyImage::ACTIVE) continue;
         //        emit messageAvailable(it->baseName + " : Modeling the sky ...", "controller");
         it->processingStatus->Skysub = false;
-        it->setupData(scienceData->isTaskRepeated, false, true, backupDirName);
+//        it->setupData(scienceData->isTaskRepeated, false, true, backupDirName);
+        it->setupData(scienceData->isTaskRepeated, true, false, backupDirName);
         if (!it->successProcessing) {
             abortProcess = true;
             continue;
